@@ -2,7 +2,9 @@ angular.module('contactsApp')
 .directive('addressbook', function() {
 	return {
 		restrict: 'A', // has to be an attribute to work with core css
-		scope: {},
+		scope: {
+			index: '@'
+		},
 		controller: 'addressbookCtrl',
 		controllerAs: 'ctrl',
 		bindToController: {
