@@ -1,4 +1,5 @@
-app.controller('contactCtrl', ['$route', '$routeParams', function($route, $routeParams) {
+angular.module('contactsApp')
+.controller('contactCtrl', function($route, $routeParams) {
 	var ctrl = this;
 
 	ctrl.openContact = function() {
@@ -6,7 +7,4 @@ app.controller('contactCtrl', ['$route', '$routeParams', function($route, $route
 			gid: $routeParams.gid,
 			uid: ctrl.contact.uid()});
 	};
-
-	console.log("Contact: ",ctrl.contact);
-
-}]);
+});
