@@ -6,17 +6,17 @@ angular.module('contactsApp')
 			data: {},
 			props: {},
 
+			dateProperties: ['bday', 'anniversary', 'deathdate'],
+
 			addressBookId: addressBook.displayName,
 
-			rev: function(value) {
-				var model = this;
-				if (angular.isDefined(value)) {
-					// setter
-					return model.setProperty('rev', { value: value });
-				} else {
-					// getter
-					return model.getProperty('rev').value;
+			version: function() {
+				var property = this.getProperty('version');
+				if(property) {
+					return property.value;
 				}
+
+				return undefined;
 			},
 
 			uid: function(value) {
@@ -47,7 +47,9 @@ angular.module('contactsApp')
 					}
 					property = model.getProperty('n');
 					if(property) {
-						return property.value.join();
+						return property.value.filter(function(elem) {
+							return elem;
+						}).join(' ');
 					}
 					return undefined;
 				}
@@ -137,23 +139,54 @@ angular.module('contactsApp')
 				} else {
 					// getter
 					var property = this.getProperty('categories');
-					if(property && property.value.length > 0) {
-						return property.value.split(',');
-					} else {
+					if(!property) {
 						return [];
 					}
+					if (angular.isArray(property.value)) {
+						return property.value;
+					}
+					return [property.value];
 				}
 			},
 
+			formatDateAsRFC6350: function(name, data) {
+				if (_.isUndefined(data) || _.isUndefined(data.value)) {
+					return data;
+				}
+				if (this.dateProperties.indexOf(name) !== -1) {
+					var match = data.value.match(/^(\d{4})-(\d{2})-(\d{2})$/);
+					if (match) {
+						data.value = match[1] + match[2] + match[3];
+					}
+				}
+
+				return data;
+			},
+
+			formatDateForDisplay: function(name, data) {
+				if (_.isUndefined(data) || _.isUndefined(data.value)) {
+					return data;
+				}
+				if (this.dateProperties.indexOf(name) !== -1) {
+					var match = data.value.match(/^(\d{4})(\d{2})(\d{2})$/);
+					if (match) {
+						data.value = match[1] + '-' + match[2] + '-' + match[3];
+					}
+				}
+
+				return data;
+			},
+
 			getProperty: function(name) {
 				if (this.props[name]) {
-					return this.props[name][0];
+					return this.formatDateForDisplay(name, this.props[name][0]);
 				} else {
 					return undefined;
 				}
 			},
 			addProperty: function(name, data) {
 				data = angular.copy(data);
+				data = this.formatDateAsRFC6350(name, data);
 				if(!this.props[name]) {
 					this.props[name] = [];
 				}
@@ -168,6 +201,7 @@ angular.module('contactsApp')
 				if(!this.props[name]) {
 					this.props[name] = [];
 				}
+				data = this.formatDateAsRFC6350(name, data);
 				this.props[name][0] = data;
 
 				// keep vCard in sync
@@ -184,9 +218,38 @@ angular.module('contactsApp')
 				this.data.url = addressBook.url + uid + '.vcf';
 			},
 
+			getISODate: function(date) {
+				function pad(number) {
+					if (number < 10) {
+						return '0' + number;
+					}
+					return '' + number;
+				}
+
+				return date.getUTCFullYear() + '' +
+						pad(date.getUTCMonth() + 1) +
+						pad(date.getUTCDate()) +
+						'T' + pad(date.getUTCHours()) +
+						pad(date.getUTCMinutes()) +
+						pad(date.getUTCSeconds());
+			},
+
 			syncVCard: function() {
+
+				this.setProperty('rev', { value: this.getISODate(new Date()) });
+				var self = this;
+
+				_.each(this.dateProperties, function(name) {
+					if (!_.isUndefined(self.props[name]) && !_.isUndefined(self.props[name][0])) {
+						// Set dates again to make sure they are in RFC-6350 format
+						self.setProperty(name, self.props[name][0]);
+					}
+				});
+				// force fn to be set
+				this.fullName(this.fullName());
+
 				// keep vCard in sync
-				this.data.addressData = $filter('JSON2vCard')(this.props);
+				self.data.addressData = $filter('JSON2vCard')(self.props);
 			},
 
 			matches: function(pattern) {
@@ -232,6 +295,10 @@ angular.module('contactsApp')
 		var property = this.getProperty('categories');
 		if(!property) {
 			this.categories('');
+		} else {
+			if (angular.isString(property.value)) {
+				this.categories([property.value]);
+			}
 		}
 	};
 });
