@@ -93,6 +93,9 @@ angular.module('contactsApp')
 		newContact.uid(newUid);
 		newContact.setUrl(addressBook, newUid);
 		newContact.addressBookId = addressBook.displayName;
+		if (_.isUndefined(newContact.fullName()) || newContact.fullName() === '') {
+			newContact.fullName(t('contacts', 'New contact'));
+		}
 
 		return DavClient.createCard(
 			addressBook,
@@ -105,8 +108,15 @@ angular.module('contactsApp')
 			contacts.put(newUid, newContact);
 			notifyObservers('create', newUid);
 			return newContact;
-		}).catch(function(e) {
-			OC.Notification.showTemporary(t('contacts', 'Contact could not be created.'));
+		}).catch(function(xhr) {
+			var msg = t('contacts', 'Contact could not be created.');
+			if (!angular.isUndefined(xhr) && !angular.isUndefined(xhr.responseXML) && !angular.isUndefined(xhr.responseXML.getElementsByTagNameNS('http://sabredav.org/ns', 'message'))) {
+				if ($(xhr.responseXML.getElementsByTagNameNS('http://sabredav.org/ns', 'message')).text()) {
+					msg = $(xhr.responseXML.getElementsByTagNameNS('http://sabredav.org/ns', 'message')).text();
+				}
+			}
+
+			OC.Notification.showTemporary(msg);
 		});
 	};
 
@@ -126,9 +136,19 @@ angular.module('contactsApp')
 		var num = 1;
 		for(var i in singleVCards) {
 			var newContact = new Contact(addressBook, {addressData: singleVCards[i]});
+			if (['3.0', '4.0'].indexOf(newContact.version()) < 0) {
+				if (progressCallback) {
+					progressCallback(num / singleVCards.length);
+				}
+				OC.Notification.showTemporary(t('contacts', 'Only VCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported.'));
+				num++;
+				continue;
+			}
 			this.create(newContact, addressBook).then(function() {
 				// Update the progress indicator
-				if (progressCallback) progressCallback(num/singleVCards.length);
+				if (progressCallback) {
+					progressCallback(num / singleVCards.length);
+				}
 				num++;
 			});
 		}
@@ -151,8 +171,6 @@ angular.module('contactsApp')
 
 	this.update = function(contact) {
 		// update rev field
-		contact.rev(new Date().toISOString());
-
 		contact.syncVCard();
 
 		// update contact on server
