@@ -1,6 +1,7 @@
-app.service('DavClient', function() {
+angular.module('contactsApp')
+.service('DavClient', function() {
 	var xhr = new dav.transport.Basic(
 		new dav.Credentials()
 	);
 	return new dav.Client(xhr);
-});
\ No newline at end of file
+});
