@@ -2,6 +2,11 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Kontakty",
+    "Download" : "Stáhnout",
+    "Delete Addressbook" : "Odstranit Adresář",
+    "Share with users or groups" : "Sdílet s uživateli nebo skupinami",
+    "Delete" : "Smazat",
+    "can edit" : "lze upravovat",
     "Address book name" : "Název adresáře kontaktů",
     "Import" : "Importovat",
     "The selected image is too big (max 1MB)" : "Zvolený obrázek je příliš velký (max 1MB)",
@@ -10,7 +15,6 @@ OC.L10N.register(
     "Organization" : "Organizace",
     "Title" : "Název",
     "Add field ..." : "Přidat pole...",
-    "+ New contact" : "+ Nový kontakt",
     "No search result for {query}" : "Žádný nález pro {query}",
     "_%n contact_::_%n contacts_" : ["%n kontakt","%n kontakty","%n kontaktů"],
     "Post office box" : "Poštovní schránka",
@@ -29,6 +33,7 @@ OC.L10N.register(
     "Not grouped" : "Neseskupené",
     "New contact" : "Nový kontakt",
     "{addressbook} shared by {owner}" : "{addressbook} sdílí {owner}",
+    "Contact could not be created." : "Kontakt se nepodařilo vytvořit.",
     "No contacts in file. Only VCard files are allowed." : "Žádné kontakty v souboru. Pouze soubory vCard jsou povoleny.",
     "Nickname" : "Přezdívka",
     "Detailed name" : "Jméno podrobně",
