@@ -2,6 +2,14 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Kontakte",
+    "Copy Url to clipboard" : "URL in die Zwischenablage kopieren",
+    "Download" : "Herunterladen",
+    "ShowURL" : "URL anzeigen",
+    "Share Addressbook" : "Adressbuch teilen",
+    "Delete Addressbook" : "Adressbuch löschen",
+    "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
+    "Delete" : "Löschen",
+    "can edit" : "kann bearbeiten",
     "Address book name" : "Adressbuch Name",
     "Import" : "Importieren",
     "The selected image is too big (max 1MB)" : "Das ausgewählte Bild ist zu groß (max. 1MB)",
@@ -10,7 +18,6 @@ OC.L10N.register(
     "Organization" : "Organisation",
     "Title" : "Titel",
     "Add field ..." : "Feld hinzufügen …",
-    "+ New contact" : "+ Neuer Kontakt",
     "No search result for {query}" : "Keine Suchergebnisse zu {query}",
     "_%n contact_::_%n contacts_" : ["%n Kontakt","%n Kontakte"],
     "Post office box" : "Postfach",
@@ -29,7 +36,9 @@ OC.L10N.register(
     "Not grouped" : "Nicht gruppiert",
     "New contact" : "Neuer Kontakt",
     "{addressbook} shared by {owner}" : "{addressbook} geteilt von {owner}",
+    "Contact could not be created." : "Kontakt konnte nicht erstellt werden.",
     "No contacts in file. Only VCard files are allowed." : "Keine Kontakte in der Datei. Nur VCard-Dateien sind erlaubt.",
+    "Only VCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Nur VCard-Version 4.0 (RFC6350) oder Version 3.0 (RFC2426) werden unterstützt.",
     "Nickname" : "Spitzname",
     "Detailed name" : "Detaillierter Name",
     "Notes" : "Notizen",
