@@ -2,6 +2,14 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Contactos",
+    "Copy Url to clipboard" : "Copiar URL al portapapeles",
+    "Download" : "Descargar",
+    "ShowURL" : "Mostrar URL",
+    "Share Addressbook" : "Compartir libreta de direcciones",
+    "Delete Addressbook" : "Eliminar libreta de contactos",
+    "Share with users or groups" : "Compartir con usuarios o grupos",
+    "Delete" : "Eliminar",
+    "can edit" : "puede editar",
     "Address book name" : "Nombre de libreta de direcciones",
     "Import" : "Importar",
     "The selected image is too big (max 1MB)" : "La imagen seleccionada es demasiada grande (máximo 1MB)",
@@ -10,7 +18,6 @@ OC.L10N.register(
     "Organization" : "Organización",
     "Title" : "Título",
     "Add field ..." : "Añadir campo ...",
-    "+ New contact" : "+ Nuevo contacto",
     "No search result for {query}" : "Sin resultados para {query}",
     "_%n contact_::_%n contacts_" : ["%n contacto","%n contactos"],
     "Post office box" : "Apartado de correos",
@@ -29,7 +36,9 @@ OC.L10N.register(
     "Not grouped" : "No agrupado",
     "New contact" : "Nuevo contacto",
     "{addressbook} shared by {owner}" : "{addressbook} compartido por {owner}",
+    "Contact could not be created." : "No se puede crear el contacto.",
     "No contacts in file. Only VCard files are allowed." : "No hay contactos en el archivo. Solamente se permiten archivos VCard.",
+    "Only VCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Sólo están soportados los formatos VCard versión 4.0 (RFC6350) o versión 3.0 (RFC2426).",
     "Nickname" : "Apodo",
     "Detailed name" : "Nombre",
     "Notes" : "Notas",
