@@ -2,14 +2,20 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Kontaktid",
+    "Download" : "Lae alla",
+    "Delete Addressbook" : "Kustuta aadressiraamat",
+    "Delete" : "Kustuta",
+    "can edit" : "saab muuta",
     "Address book name" : "Aadressiraamatu nimi",
     "Import" : "Impordi",
+    "The selected image is too big (max 1MB)" : "Valitud pilt on liiga suur (maks 1MB)",
     "No contacts in here" : "Ühtegi kontakti pole",
     "Name" : "Nimi",
     "Organization" : "Organisatsioon",
     "Title" : "Pealkiri",
     "Add field ..." : "Lisa väli ...",
     "No search result for {query}" : "Otsingutulemused sõnadele {query}",
+    "Post office box" : "Postkast",
     "Postal code" : "Postiindeks",
     "City" : "Linn",
     "State or province" : "Maakond",
@@ -19,11 +25,16 @@ OC.L10N.register(
     "Last name" : "Perekonnanimi",
     "First name" : "Eesnimi",
     "Additional names" : "Lisanimed",
+    "Prefix" : "Eesliide",
+    "Suffix" : "Järelliide",
     "All contacts" : "Kõik kontaktid",
     "Not grouped" : "Pole grupeeritud",
     "New contact" : "Uus kontakt",
     "{addressbook} shared by {owner}" : "{owner} jagas aadressiraamatut {addressbook}",
+    "Contact could not be created." : "Kontakti loomine ebaõnnestus.",
+    "No contacts in file. Only VCard files are allowed." : "Failis pole kontakte. Lubatud on ainult VCard.",
     "Nickname" : "Hüüdnimi",
+    "Detailed name" : "Üksikasjalik nimi",
     "Notes" : "Märkmed",
     "Website" : "Veebileht",
     "Home" : "Kodu",
@@ -31,6 +42,8 @@ OC.L10N.register(
     "Other" : "Muu",
     "Groups" : "Grupid",
     "Birthday" : "Sünnipäev",
+    "Anniversary" : "Aastapäev",
+    "Date of death" : "Surma kuupäev",
     "Email" : "E-post",
     "Instant messaging" : "Kiirõnumid",
     "Phone" : "Telefon",
@@ -40,6 +53,7 @@ OC.L10N.register(
     "Fax work" : "Faks tööl",
     "Pager" : "Piipar",
     "Voice" : "Hääl",
+    "Social network" : "Sotsiaalvõrk",
     "Settings" : "Seaded"
 },
 "nplurals=2; plural=(n != 1);");
