@@ -2,6 +2,13 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Yhteystiedot",
+    "Copy Url to clipboard" : "Kopioi osoite leikepöydälle",
+    "Download" : "Lataa",
+    "Share Addressbook" : "Jaa osoitekirja",
+    "Delete Addressbook" : "Poista osoitekirja",
+    "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
+    "Delete" : "Poista",
+    "can edit" : "voi muokata",
     "Address book name" : "Osoitekirjan nimi",
     "Import" : "Tuo",
     "The selected image is too big (max 1MB)" : "Valittu kuva on liian suuri kooltaan (enintään 1 Mt)",
@@ -10,7 +17,6 @@ OC.L10N.register(
     "Organization" : "Organisaatio",
     "Title" : "Otsikko",
     "Add field ..." : "Lisää kenttä...",
-    "+ New contact" : "+ Uusi yhteystieto",
     "No search result for {query}" : "Ei tuloksia haulle {query}",
     "_%n contact_::_%n contacts_" : ["%n yhteystieto","%n yhteystietoa"],
     "Post office box" : "Postilokero",
@@ -29,7 +35,9 @@ OC.L10N.register(
     "Not grouped" : "Ei ryhmitelty",
     "New contact" : "Uusi yhteystieto",
     "{addressbook} shared by {owner}" : "Osoitekirjan {addressbook} jakoi {owner}",
+    "Contact could not be created." : "Yhteystiedon luominen ei onnistunut.",
     "No contacts in file. Only VCard files are allowed." : "Ei yhteystietoja tiedostossa. Vain vCard-tiedostot ovat sallittuja.",
+    "Only VCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Vain VCardin versiot 4.0 (RFC6350) ja 3.0 (RFC2426) ovat tuettuja.",
     "Nickname" : "Kutsumanimi",
     "Detailed name" : "Täsmällinen nimi",
     "Notes" : "Huomiot",
