@@ -2,6 +2,10 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Contacts",
+    "Download" : "Télécharger",
+    "Share with users or groups" : "Partager avec des utilisateurs ou des groupes",
+    "Delete" : "Supprimer",
+    "can edit" : "peut modifier",
     "Address book name" : "Nom du carnet d'adresses",
     "Import" : "Importer",
     "The selected image is too big (max 1MB)" : "L'image sélectionnée est trop volumineuse (1Mo max)",
@@ -10,7 +14,6 @@ OC.L10N.register(
     "Organization" : "Société",
     "Title" : "Titre",
     "Add field ..." : "Ajouter un champ ...",
-    "+ New contact" : "+ Nouveau contact",
     "No search result for {query}" : "Aucun résultat pour {query}",
     "_%n contact_::_%n contacts_" : ["%n contact","%n contacts"],
     "Post office box" : "Boîte postale",
@@ -29,6 +32,7 @@ OC.L10N.register(
     "Not grouped" : "Non groupés",
     "New contact" : "Nouveau contact",
     "{addressbook} shared by {owner}" : "{addressbook} partagé par {owner}",
+    "Contact could not be created." : "Ce contact n'a pu être créé.",
     "No contacts in file. Only VCard files are allowed." : "Aucun contact dans ce fichier. Seulement les fichiers VCard sont autorisés.",
     "Nickname" : "Surnom",
     "Detailed name" : "Nom complet",
