@@ -2,6 +2,10 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "אנשי קשר",
+    "Download" : "הורדה",
+    "Share with users or groups" : "שיתוף עם משתמשים או קבוצות",
+    "Delete" : "מחיקה",
+    "can edit" : "ניתן לערוך",
     "Address book name" : "שם ספר כתובות",
     "Import" : "יבוא",
     "The selected image is too big (max 1MB)" : "התמונה הנבחרת גדולה מדי (מקסימום 1 מגה בייט)",
@@ -10,7 +14,6 @@ OC.L10N.register(
     "Organization" : "ארגון",
     "Title" : "כותרת",
     "Add field ..." : "הוספת שדה...",
-    "+ New contact" : "+ איש קשר חדש",
     "No search result for {query}" : "אין תוצאות חיפוש עבור {query}",
     "_%n contact_::_%n contacts_" : ["%n איש קשר","%n אנשי קשר"],
     "Post office box" : "תיבת דואר",
@@ -29,6 +32,7 @@ OC.L10N.register(
     "Not grouped" : "לא שויך לקבוצה",
     "New contact" : "איש קשר חדש",
     "{addressbook} shared by {owner}" : "{addressbook} שותף על ידי {owner}",
+    "Contact could not be created." : "לא ניתן היה ליצור איש קשר.",
     "No contacts in file. Only VCard files are allowed." : "אין אנשי קשר בקובץ. רק קובצי VCard ניתנים לשימוש.",
     "Nickname" : "כינוי",
     "Detailed name" : "פרטי שם",
