@@ -2,6 +2,14 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Contatti",
+    "Copy Url to clipboard" : "Copia URL negli appunti",
+    "Download" : "Scarica",
+    "ShowURL" : "Mostra URL",
+    "Share Addressbook" : "Condividi rubrica",
+    "Delete Addressbook" : "Elimina rubrica",
+    "Share with users or groups" : "Condividi con utenti o gruppi",
+    "Delete" : "Elimina",
+    "can edit" : "può modificare",
     "Address book name" : "Nome della rubrica",
     "Import" : "Importa",
     "The selected image is too big (max 1MB)" : "L'immagine selezionata è troppo grande (max 1MB)",
@@ -10,7 +18,6 @@ OC.L10N.register(
     "Organization" : "Organizzazione",
     "Title" : "Titolo",
     "Add field ..." : "Aggiungi campo...",
-    "+ New contact" : "+ Nuovo contatto",
     "No search result for {query}" : "Nessun risultato di ricerca per {query}",
     "_%n contact_::_%n contacts_" : ["%n contatto","%n contatti"],
     "Post office box" : "Casella postale",
@@ -25,11 +32,13 @@ OC.L10N.register(
     "Additional names" : "Nomi aggiuntivi",
     "Prefix" : "Prefisso",
     "Suffix" : "Suffisso",
-    "All contacts" : "Tuuti i contatti",
+    "All contacts" : "Tutti i contatti",
     "Not grouped" : "Non raggruppati",
     "New contact" : "Nuovo contatto",
     "{addressbook} shared by {owner}" : "{addressbook} condivisa da {owner}",
+    "Contact could not be created." : "Il contatto non può essere creato.",
     "No contacts in file. Only VCard files are allowed." : "Nessun contatto nel file. Sono consentiti solo file vCard.",
+    "Only VCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Sono supportare solo vCard versione 4.0 (RFC6350) o versione 3.0 (RFC2426).",
     "Nickname" : "Pseudonimo",
     "Detailed name" : "Nome dettagliato",
     "Notes" : "Note",
