@@ -2,6 +2,12 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "アドレス帳",
+    "Copy Url to clipboard" : "クリップボードにURLをコピーしました",
+    "Download" : "ダウンロード",
+    "Delete Addressbook" : "アドレス帳を削除",
+    "Share with users or groups" : "ユーザーもしくはグループと共有",
+    "Delete" : "削除",
+    "can edit" : "編集を許可",
     "Address book name" : "アドレス帳名",
     "Import" : "インポート",
     "The selected image is too big (max 1MB)" : "選択した画像容量が大きすぎます (最大1 MB)",
@@ -10,7 +16,6 @@ OC.L10N.register(
     "Organization" : "所属",
     "Title" : "タイトル",
     "Add field ..." : "項目を追加",
-    "+ New contact" : "+新しい連絡先",
     "No search result for {query}" : "{query} に関する検索結果はありません。",
     "_%n contact_::_%n contacts_" : ["件の連絡先"],
     "Post office box" : "私書箱",
@@ -29,6 +34,7 @@ OC.L10N.register(
     "Not grouped" : "グループ化されていません",
     "New contact" : "新しい連絡先",
     "{addressbook} shared by {owner}" : " {owner}と共有中の{addressbook} ",
+    "Contact could not be created." : "連絡先を作成できませんでした。",
     "No contacts in file. Only VCard files are allowed." : "コンタクトがファイルにありません。VCardファイルのみが有効です。",
     "Nickname" : "ニックネーム",
     "Detailed name" : "詳細名",
