@@ -2,6 +2,14 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Contactpersonen",
+    "Copy Url to clipboard" : "Kopiëren URL naar klembord",
+    "Download" : "Downloaden",
+    "ShowURL" : "ShowURL",
+    "Share Addressbook" : "Delen adresboek",
+    "Delete Addressbook" : "Verwijder adresboek",
+    "Share with users or groups" : "Delen met gebruikers of groepen",
+    "Delete" : "Verwijderen",
+    "can edit" : "kan wijzigen",
     "Address book name" : "Adresboek naam",
     "Import" : "Importeer",
     "The selected image is too big (max 1MB)" : "De geselecteerde afbeelding is te groot (max 1MB)",
@@ -10,7 +18,6 @@ OC.L10N.register(
     "Organization" : "Organisatie",
     "Title" : "Titel",
     "Add field ..." : "Voeg veld toe",
-    "+ New contact" : "+ Nieuwe contactpersoon",
     "No search result for {query}" : "Geen zoekresultaten voor {query}",
     "_%n contact_::_%n contacts_" : ["%n contactpersoon","%n contactpersonen"],
     "Post office box" : "Postbus",
@@ -29,7 +36,9 @@ OC.L10N.register(
     "Not grouped" : "Niet gegroepeerd",
     "New contact" : "Nieuwe contactpersoon",
     "{addressbook} shared by {owner}" : "{addressbook} gedeeld door {owner}",
+    "Contact could not be created." : "Contact kon niet worden aangemaakt.",
     "No contacts in file. Only VCard files are allowed." : "Geen contacten in bestand. Alleen VCard bestanden zijn toegestaan.",
+    "Only VCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Alleen VCard versie 4.0 (RFC6350) of versie 3.0 (RFC2426) worden ondersteund.",
     "Nickname" : "Roepnaam",
     "Detailed name" : "Gedetailleerde naam",
     "Notes" : "Notities",
