@@ -2,22 +2,33 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Contactes",
+    "Download" : "Telecargar",
+    "Delete" : "Suprimir",
+    "can edit" : "pòt modificar",
+    "Import" : "Importar",
+    "No contacts in here" : "Pas cap de contacte",
     "Name" : "Nom",
     "Organization" : "Societat",
     "Title" : "Títol",
     "Add field ..." : "Apondre un camp...",
-    "Import" : "Importar",
-    "Add contact" : "Apondre un contacte",
-    "All contacts" : "Totes los contactes",
-    "Not grouped" : "Pas gropats",
-    "Postal Code" : "Còdi postal",
+    "_%n contact_::_%n contacts_" : ["%n contacte","%n contactes"],
+    "Post office box" : "Bóstia postala",
+    "Postal code" : "Còde postal",
     "City" : "Vila",
     "State or province" : "Estat o region",
     "Country" : "País",
     "Address" : "Adreça",
     "(new group)" : "(grop novèl)",
+    "Last name" : "Nom",
+    "First name" : "Prenom",
+    "Additional names" : "Noms suplementaris",
+    "Prefix" : "Prefix",
+    "Suffix" : "Sufix",
+    "All contacts" : "Totes los contactes",
+    "Not grouped" : "Pas gropats",
     "New contact" : "Contacte novèl",
     "Nickname" : "Escais",
+    "Detailed name" : "Nom complet",
     "Notes" : "Nòtas",
     "Website" : "Site web",
     "Federated Cloud ID" : "Federated Cloud ID",
@@ -26,13 +37,17 @@ OC.L10N.register(
     "Other" : "Autre",
     "Groups" : "Gropes",
     "Birthday" : "Anniversari",
+    "Anniversary" : "Anniversari",
     "Email" : "Adreça corrièl",
     "Instant messaging" : "Messatjariá instantanèa",
     "Phone" : "Telefòn",
     "Mobile" : "Mobil",
     "Fax" : "Fax",
+    "Fax home" : "Fax personal",
+    "Fax work" : "Fax pro",
     "Pager" : "Messatgièr",
     "Voice" : "Votz",
+    "Social network" : "Ret sociala",
     "Settings" : "Paramètres"
 },
 "nplurals=2; plural=(n > 1);");
