@@ -2,24 +2,29 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Contacte",
+    "Download" : "Descarcă",
+    "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
+    "Delete" : "Șterge",
+    "can edit" : "poate edita",
     "Address book name" : "Numele listă de contacte",
     "Import" : "Importă",
+    "The selected image is too big (max 1MB)" : "Imaginea selectată este prea mare (maxim 1 MB)",
     "No contacts in here" : "Niciun contact aici",
     "Name" : "Nume",
     "Organization" : "Organizație",
     "Title" : "Titlu",
     "Add field ..." : "Adaugă câmp ...",
-    "Add contact" : "Adaugă contact",
     "No search result for {query}" : "Niciun rezultat pentru {query}",
-    "All contacts" : "Toate contactele",
-    "Not grouped" : "Negrupate",
-    "Post Office Box" : "Căsuță poștală",
-    "Postal Code" : "Cod poștal",
+    "Postal code" : "Codul poștal",
     "City" : "Oraș",
     "State or province" : "Județ sau provincie",
     "Country" : "Țară",
     "Address" : "Adresă",
     "(new group)" : "(grup nou)",
+    "Last name" : "Nume",
+    "First name" : "Prenume",
+    "All contacts" : "Toate contactele",
+    "Not grouped" : "Negrupate",
     "New contact" : "Contact nou ",
     "{addressbook} shared by {owner}" : "{addressbook} partajat de {owner}",
     "No contacts in file. Only VCard files are allowed." : "Niciun contact în fișier. Doar fișiere VCard sunt suportate.",
@@ -41,7 +46,6 @@ OC.L10N.register(
     "Fax work" : "Fax - serviciu",
     "Pager" : "Pager",
     "Voice" : "Voce",
-    "Social Network" : "Rețea socială",
     "Settings" : "Setări"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
