@@ -2,6 +2,11 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Контакты",
+    "Copy Url to clipboard" : "Копировать адрес в буфер обмена",
+    "Download" : "Скачать",
+    "Share with users or groups" : "Общий доступ с пользователями или группами",
+    "Delete" : "Удалить",
+    "can edit" : "можно редактировать",
     "Address book name" : "Название адресной книги",
     "Import" : "Импорт",
     "The selected image is too big (max 1MB)" : "Выбранное изображение слишком велико (макс. 1 МБ)",
@@ -10,9 +15,8 @@ OC.L10N.register(
     "Organization" : "Организация",
     "Title" : "Должность",
     "Add field ..." : "Добавить поле ...",
-    "+ New contact" : "+ Новый контакт",
     "No search result for {query}" : "По запросу {query} ничего не найдено",
-    "_%n contact_::_%n contacts_" : ["%n контакт","%n контакт","%n контакт","%n контактов"],
+    "_%n contact_::_%n contacts_" : ["%n контакт","%n контакта","%n контактов","%n контактов"],
     "Post office box" : "Почтовый ящик",
     "Postal code" : "Почтовый индекс",
     "City" : "Город",
@@ -29,6 +33,7 @@ OC.L10N.register(
     "Not grouped" : "Без группы",
     "New contact" : "Новый контакт",
     "{addressbook} shared by {owner}" : "{addressbook} поделился {owner}",
+    "Contact could not be created." : "Не удалось создать контакт.",
     "No contacts in file. Only VCard files are allowed." : "В файле нет контактов. Допустимы только файлы VCard.",
     "Nickname" : "Псевдоним",
     "Detailed name" : "Подробное имя",
@@ -47,8 +52,8 @@ OC.L10N.register(
     "Phone" : "Телефон",
     "Mobile" : "Мобильный",
     "Fax" : "Факс",
-    "Fax home" : "Домашний факс",
-    "Fax work" : "Факс работы",
+    "Fax home" : "Факс домашний",
+    "Fax work" : "Факс рабочий",
     "Pager" : "Пейджер",
     "Voice" : "Голосовая почта",
     "Social network" : "Социальная сеть",
