@@ -2,6 +2,14 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Stiki",
+    "Copy Url to clipboard" : "Kopiraj naslov URL v odložišče",
+    "Download" : "Prejmi",
+    "ShowURL" : "Pokaži naslov URL",
+    "Share Addressbook" : "Souporaba imenika",
+    "Delete Addressbook" : "Izbriši imenik",
+    "Share with users or groups" : "Souporaba z uporabniki ali skupinami",
+    "Delete" : "Izbriši",
+    "can edit" : "lahko ureja",
     "Address book name" : "Ime imenika",
     "Import" : "Uvozi",
     "The selected image is too big (max 1MB)" : "Izbrana slika je prevelika (omejitev je 1 MB).",
@@ -10,7 +18,6 @@ OC.L10N.register(
     "Organization" : "Ustanova",
     "Title" : "Naslov",
     "Add field ..." : "Dodaj polje ...",
-    "+ New contact" : "+ Nov stik",
     "No search result for {query}" : "Ni zadetkov iskanja za {query}",
     "_%n contact_::_%n contacts_" : ["%n stik","%n stika","%n stiki","%n stikov"],
     "Post office box" : "Poštni predal",
@@ -29,7 +36,9 @@ OC.L10N.register(
     "Not grouped" : "Brez skupine",
     "New contact" : "Nov stik",
     "{addressbook} shared by {owner}" : "Souporabo imenika {addressbook} je omogočil uporabnik {owner}",
+    "Contact could not be created." : "Stika ni mogoče ustvariti.",
     "No contacts in file. Only VCard files are allowed." : "V datoteki ni vpisanih stikov. Dovoljeni so le vpisi datotek VCard.",
+    "Only VCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Podprti sta le različici VCard 4.0 (RFC6350) in VCard 3.0 (RFC2426).",
     "Nickname" : "Vzdevek",
     "Detailed name" : "Podrobno ime",
     "Notes" : "Sporočilca",
