@@ -2,6 +2,13 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Kontakte",
+    "Copy Url to clipboard" : "Kopjoje URL-në në të papastër",
+    "Download" : "Shkarkoje",
+    "Share Addressbook" : "Ndajeni Librin e Adresave Me të Tjerë",
+    "Delete Addressbook" : "Fshijeni Librin e Adresave",
+    "Share with users or groups" : "Ndajeni me përdorues ose grupe",
+    "Delete" : "Fshije",
+    "can edit" : "mund të përpunojnë",
     "Address book name" : "Emër libri adresash",
     "Import" : "Importoje",
     "The selected image is too big (max 1MB)" : "Figura e përzgjedhur është shumë e madhe (maksimumi 1MB)",
@@ -10,7 +17,6 @@ OC.L10N.register(
     "Organization" : "Organizëm",
     "Title" : "Titull",
     "Add field ..." : "Shtoni fushë...",
-    "+ New contact" : "+ Kontakt i ri",
     "No search result for {query}" : "S’pat përfundime kërkimi për {query}",
     "_%n contact_::_%n contacts_" : ["%n kontakt","%n kontakte"],
     "Post office box" : "Kuti postare në postë",
@@ -29,7 +35,9 @@ OC.L10N.register(
     "Not grouped" : "I pagrupuar",
     "New contact" : "Kontakt i ri",
     "{addressbook} shared by {owner}" : "{addressbook} ndarë nga {owner}",
+    "Contact could not be created." : "Kontakti s’u krijua dot.",
     "No contacts in file. Only VCard files are allowed." : "S’ka kontakte në kartelë. Lejohen vetëm kartela VCard.",
+    "Only VCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Mbulohen vetëm VCard version 4.0 (RFC6350) ose version 3.0 (RFC2426).",
     "Nickname" : "Nofkë",
     "Detailed name" : "Emri i hollësishëm",
     "Notes" : "Shënime",
