@@ -18,31 +18,20 @@ use OCP\AppFramework\Http\TemplateResponse;
 
 class PageControllerTest extends PHPUnit_Framework_TestCase {
 
+	/** @var PageController */
 	private $controller;
-	private $userId = 'john';
 
 	public function setUp() {
 		$request = $this->getMockBuilder('OCP\IRequest')->getMock();
 
-		$this->controller = new PageController(
-			'contacts', $request, $this->userId
-		);
+		$this->controller = new PageController('contacts', $request);
 	}
 
-
 	public function testIndex() {
 		$result = $this->controller->index();
 
-		$this->assertEquals(['user' => 'john'], $result->getParams());
 		$this->assertEquals('main', $result->getTemplateName());
 		$this->assertTrue($result instanceof TemplateResponse);
 	}
 
-
-	public function testEcho() {
-		$result = $this->controller->doEcho('hi');
-		$this->assertEquals(['echo' => 'hi'], $result->getData());
-	}
-
-
 }
